#!/usr/bin/python
# -*- coding: utf8 -*-
# -*- Mode: Python; py-indent-offset: 4 -*-
# pylint: disable=C0103

"""Db adapter for phase project"""

import logging
from time import tzname
from datetime import datetime
from pymongo import MongoClient

CLIENT = MongoClient('localhost', 27017)
DB = CLIENT.phase
ERRORS_COLLECTION = DB.errors
SERIES_COLLECTION = DB.series
MESSAGES_COLLECTION = DB.messages
DEVICES_COLLECTION = DB.devices

LOGGER = logging.getLogger("timeserieslogger")


def get_devices_informations(device_id):
    """Return devices information stored in DB

    :param device_id: Device identifiant
    :type device_id: str.
    """
    return DEVICES_COLLECTION.find_one({"deviceID": device_id})


def insert_message(message):
    """Insert message in DB

        :param message: Representation of a message
        :type message: dict.
    """
    MESSAGES_COLLECTION.insert(message)


def insert_series(series):
    """Insert series in DB

        :param series: Representation of a series
        :type series: dict.
    """
    SERIES_COLLECTION.insert(series)


def create_series(value, variable_id, message):
    """Transform param into a series Object

        :param value: Value of the series
        :type value: str.

        :param variable_id: Variable identifiant
        :type variable_id: str.

        :param message: Information about value date
        :type message: dict.
    """
    return {
        "variableID": variable_id,
        "siteID": message["siteID"],
        "value": value,
        "date": message["date"],
        "dstTimezone": message["dstTimezone"],
        "nonDstTimezone": message["nonDstTimezone"]
    }


def insert_error(message):
    """Function that store error in errors collection and in log

        :param message: Error to insert in DB
        :type message: str.
    """
    LOGGER.error(message["message"])
    ERRORS_COLLECTION.insert(message)


def store_error(error):
    """Function that create valid error message

        :param error: Mal formed message
        :type error: str.
    """
    message = {
        "message": error,
        "deviceID": "system",
        "siteID": "system",
        "date": datetime.utcnow().isoformat('T'),
        'dstTimezone': tzname[1],
        'nonDstTimezone': tzname[0]
    }
    insert_error(message)


def get_last_series(site_id, variable_id):
    """Return last record for series registration
    """
    return SERIES_COLLECTION.find({
        "siteID": site_id,
        "variableID": variable_id}).sort("_id", -1).limit(1)
